@@ -36,7 +36,20 @@ class GoogleLoginFailed(Exception):
     """
     Exception raised on login failure and other authorization problems.
     """
-    pass
+    def __init__(self, msg, detail=""):
+        if detail:
+            # Google returns bodies like:
+            #
+            # Error=AccountDisabled
+            # Url=https://www.google.com/accounts/ErrorMsg?Email=a%40gmail.com&service=reader&id=adis&timeStmp=1352706633&secTok=.AG5fkS9UcwdwCcoxK7YRqWRQ_3U22aa6IQ%3D%3D
+            #
+            # where the latter yields textual page like "Sorry, your account has been disabled"
+            m = re.search('^Error=(.*)$', detail, re.M)
+            if m:
+                msg += "(" + m.group(1) + ")"
+
+        super(GoogleLoginFailed, self).__init__(msg)
+        
 class GoogleOperationFailed(Exception):
     """
     Exception raised when Google rejects some operation.
@@ -431,7 +444,7 @@ class GoogleReaderClient(object):
             f = urllib2.urlopen( request )
         except urllib2.HTTPError as e:
             if e.code == 403:
-                raise GoogleLoginFailed("%s (%s)" % (e.reason, e.read().rstrip()))
+                raise GoogleLoginFailed(e.msg, e.read().rstrip())
             else:
                 raise
         result = f.read()
@@ -440,7 +453,7 @@ class GoogleReaderClient(object):
 
         sid = re.search('Auth=(\S*)', result).group(1)
         if not sid:
-            raise GoogleLoginFailed
+            raise GoogleLoginFailed("API error, missing Auth header")
         return sid
 
     def _get_token(self):
